@@ -28,10 +28,7 @@ os.chdir( main_dir )
 
 # Add the modules directory to the python path    
 
-#suite = pywebsite.tests.load_suites(test_subdir)
 pywebsite.tests.verbose = "--verbose" in sys.argv or "-v" in sys.argv
-pywebsite.tests.test_subdir = os.path.join('pywebsite', 'tests')
-sys.path.insert( 0, pywebsite.tests.test_subdir )
 suite = pywebsite.tests.main()
 
 
